@@ -1,58 +1,59 @@
 from .edit_file import edit_file
-from .worker import worker, worker_gen
-from .screenshot import save_screenshot_to_file
-from .request_input import request_admin_input
-
+from .search_web import search_web
+from .completion import task_complete
 from .search_arxiv import search_arxiv
 from .repomap import get_code_repo_map
+from .request_input import request_admin_input
+from .screenshot import save_screenshot_to_file
+from .worker import worker, worker_gen, chatgroup
 from .click import find_and_click_element, scroll_screen
-from .search_web import search_web
-from .taskmanager import create_task, resume_task, get_all_tasks_status, get_task_result
+from .subtasks import create_task, resume_task, get_all_tasks_status, get_task_result
 
 #显式导入 aient.plugins 中的所需内容
 from ..aient.src.aient.plugins import (
-    excute_command,
     get_time,
+    read_file,
+    read_image,
+    register_tool,
+    write_to_file,
+    excute_command,
     generate_image,
     list_directory,
-    read_file,
-    run_python_script,
-    get_search_results,
-    write_to_file,
-    download_read_arxiv_pdf,
     get_url_content,
-    read_image,
+    run_python_script,
     set_readonly_path,
-    register_tool,
+    get_search_results,
+    download_read_arxiv_pdf,
 )
 
 __all__ = [
-    "edit_file",
     "worker",
-    "worker_gen",
-    "search_arxiv",
-    "get_code_repo_map",
-    # aient.plugins
-    "excute_command",
-    "read_image",
     "get_time",
-    "generate_image",
-    "list_directory",
+    "edit_file",
     "read_file",
-    "run_python_script",
-    "get_search_results",
-    "write_to_file",
-    "download_read_arxiv_pdf",
-    "get_url_content",
-    "find_and_click_element",
-    "scroll_screen",
-    "register_tool",
+    "chatgroup",
+    "worker_gen",
+    "read_image",
     "search_web",
-    "save_screenshot_to_file",
-    "set_readonly_path",
-    "request_admin_input",
     "create_task",
     "resume_task",
-    "get_all_tasks_status",
+    "search_arxiv",
+    "write_to_file",
+    "scroll_screen",
+    "register_tool",
+    "task_complete",
+    "excute_command",
+    "generate_image",
+    "list_directory",
     "get_task_result",
+    "get_url_content",
+    "set_readonly_path",
+    "get_code_repo_map",
+    "run_python_script",
+    "get_search_results",
+    "request_admin_input",
+    "get_all_tasks_status",
+    "find_and_click_element",
+    "download_read_arxiv_pdf",
+    "save_screenshot_to_file",
 ]
\ No newline at end of file
